@@ -74,7 +74,7 @@ class MagCodeSysLogHandler(logging.handlers.SysLogHandler):
         The record is formatted, and then sent to the libc syslog function. If
         exception information is present, it is NOT sent to the server.
         """
-        msg = self.format(record) + '\000'
+        msg = self.format(record)
         """
         We need to convert record level to lowercase, maybe this will
         change in the future.
